@@ -291,7 +291,7 @@ class MarketAnalyzer:
         """
         return self.base * self.df / self.df.iloc[0, :].values
 
-    def plot_perf(self, title='Performances', ax=None, show=True, **kwargs):
+    def plot_perf(self, title='Performances', ax=None, show=True,saving_png_path = None, **kwargs):
         """ Plot asset performances.
 
         Parameters
@@ -319,6 +319,9 @@ class MarketAnalyzer:
         if show:
             plt.show()
 
+        if saving_png_path is not None:
+            plt.savefig(saving_png_path, format='png')
+
     def get_corr(self, window):
         """ Get rolling cross-correlation.
 
