@@ -7,7 +7,20 @@ from scipy.optimize import Bounds, LinearConstraint, minimize
 from napoleontoolbox.utility import metrics
 import numpy as np
 from napoleontoolbox.signal import signal_utility
+from napoleontoolbox.connector import napoleon_connector
+import json
 
+def unjsonize_list_run_results(local_root_directory, list_pkl_file_name):
+    signals_list = napoleon_connector.load_pickled_list(local_root_directory=local_root_directory,
+                                                             list_pkl_file_name=list_pkl_file_name)
+    print('signals list size '+str(len(signals_list)))
+    params_list = []
+    for me_signal in signals_list:
+        ## idiosyncratic run itself
+        run_json_string = signal_utility.recover_to_sql_column_format(me_signal)
+        params = json.loads(run_json_string)
+        params_list.append(params)
+    return params_list
 
 def convert_to_sql_column_format(run):
     run = run.replace('[', 'ccg')
@@ -62,7 +75,7 @@ def roll(df, w):
     })
     return rolled_df.groupby(level=0)
 
-def f_sharpe_signals_mix(data, w):
+def f_sharpe_signals_mix(data, w, display_threshold = 0.99):
     all_signals = [col for col in data.columns if 'signal' in col]
     N_ = len(all_signals)
     w = w.reshape([1,N_])
@@ -72,6 +85,10 @@ def f_sharpe_signals_mix(data, w):
     temp_df['signal'] = tt.sum(axis=1)
     hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, print_turnover=False)
     sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
+    if np.random.rand()>display_threshold:
+        print(w)
+        print('signals mix sharpe')
+        print(sharpe_strat)
     return -sharpe_strat
 
 def expanding_zscore(signal_np_array=None, skipping_point = 5, signal_continuum_threshold = 10):
